#!/bin/sh

:<<'########################################################################'

  Usage: make_chrony-doc.sh 

This script downloads and constructs the documentation for the chrony
extension.

------------------------------------------------------------------------

Change-log: 
  2011-10-09 First version.

------------------------------------------------------------------------

This script was written in 2011 by vitex from forum.tinycorelinux.net.

To the extent possible under law, the author(s) have dedicated all
copyright and related and neighboring rights to this software to the
public domain worldwide. This software is distributed without any
warranty.

See http://creativecommons.org/publicdomain/zero/1.0/ for a copy 
of the CC0 Public Domain Dedication under which this work is 
distributed.

########################################################################

# Specify the name of the extension.
EXTENSION=chrony-doc

# Specify the base portion of the extension.
EXTENSION0=chrony

#-----------------------------------------------------------------------

# Install the extensions needed to build this extension.
tce-load -wi compiletc.tcz groff.tcz

#-----------------------------------------------------------------------

# Specify the temporary directory that will contain the build components.
TMP=/tmp/tcz

# Specify the directory in which the squashfs files will be assembled.
SQUASHFS=$TMP/squashfs 

# Specify the directory in which the submission package will be assembled.
PACKAGE=$TMP/package

#-----------------------------------------------------------------------

# Specify the location containing the software distribution.
VERSION=1.26
DOWNLOAD=http://download.tuxfamily.org/chrony/chrony-$VERSION.tar.gz

#-----------------------------------------------------------------------

# Download if necessary.
tar tzf $TMP/$(basename $DOWNLOAD) 1>/dev/null 2>&1 ||
  wget -O- $DOWNLOAD >$TMP/$(basename $DOWNLOAD)

#-----------------------------------------------------------------------

# Compute the name of the directory into which the software will be unpacked.
DIRECTORY=$TMP/$EXTENSION0-$VERSION

#-----------------------------------------------------------------------

# Unpack the software.
rm -fR $DIRECTORY
tar xzf $TMP/$(basename $DOWNLOAD) -C $TMP

#-----------------------------------------------------------------------

export CFLAGS="-march=i486 -mtune=i686 -Os -pipe"
export CXXFLAGS="-march=i486 -mtune=i686 -Os -pipe"
export LDFLAGS="-Wl,-O1"

#-----------------------------------------------------------------------

# Build the documents.
{ cd $DIRECTORY ; ./configure ; touch $TMP/TIMESTAMP ; }

#-----------------------------------------------------------------------

# Copy the documentation to $SQUASHFS/usr/local/share/$EXTENSION0/doc.

man2txt () {
  groff -T ascii -man $1 | sed -e 's/'$(echo -ne '\033')'[^m]*m//g'
}

# Convert the man pages into simple text files in 
# /usr/local/share/$EXTENSION0
mkdir -p $SQUASHFS/usr/local/share/$EXTENSION0/doc
for f in $(ls $DIRECTORY/*.[0-9])
do
  man2txt $f >$SQUASHFS/usr/local/share/$EXTENSION0/doc/$(basename $f).txt
done

# Copy the *.txt as well.
cp -R $DIRECTORY/*.txt $SQUASHFS/usr/local/share/$EXTENSION0/doc

#-----------------------------------------------------------------------

# Create $EXTENSION.tcz.info.
cat >$PACKAGE/$EXTENSION.tcz.info <<EOF
Title:          $EXTENSION.tcz
Description:    chrony - programs for keeping computer clocks accurate
Version:        $VERSION
Author:         Paul Rombouts
Original-site:  http://chrony.tuxfamily.org/
Source:         $DOWNLOAD
Copying-policy: GNU General Public License Version 2
Size:           SiZeK
Extension_by:   vitex
Comments:       From http://chrony.tuxfamily.org/:

                  Chrony is a pair of programs which are used to
                  maintain the accuracy of the system clock on a
                  computer. The two programs are called chronyd and
                  chronyc.

                  Chronyd is a daemon which runs in background on the
                  system. It obtains measurements via the network of
                  the system clock's offset relative to time servers
                  on other systems and adjusts the system time
                  accordingly. For isolated systems, the user can
                  periodically enter the correct time by hand (using
                  Chronyc). In either case, Chronyd determines the
                  rate at which the computer gains or loses time, and
                  compensates for this. Chronyd implements the NTP
                  protocol and can act as either a client or a server.

                  Chronyc provides a user interface to Chronyd for
                  monitoring its performance and configuring various
                  settings. It can do so while running on the same
                  computer as the Chronyd instance it is controlling
                  or a different computer.

            
                -----------------------------------------------------

                This extension contains the documentation files in 
                the directory /usr/local/share/doc/chrony/.

                -----------------------------------------------------

Change-log:     ----------
         	2010/04/03 First version
Current:	2011/12/14 Upgraded to 1.26
EOF

#-----------------------------------------------------------------------
